@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,10 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-__author__ = "Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)"
-__version__ = "1.4.200401.1204314"
+__author__ = "Vitaliy Zakaznikov"
+__version__ = "1.5.200604.1223022"
 __license__ = f"""
-Copyright 2019 {__author__}
+Copyright 2019 Katteli Inc.
+TestFlows Test Framework (http://testflows.com)
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
