@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,10 +43,10 @@ class Handler(HandlerBase):
         def __init__(self, name, input, output, tail=False):
             stop_event = threading.Event()
 
-            command = f"grep -E '^1,.*,\"{name}[^/]*\",' -m 1"
+            command = "grep -E '\"message_object\":1,.+\"test_name\":\"%s\"'" % name
             steps = [
-                read_and_filter_transform(input, command=command, tail=tail),
-                parse_transform(stop_event),
+                read_and_filter_transform(input, command=command, tail=tail, stop=stop_event),
+                parse_transform(),
                 short_transform(),
                 write_transform(output),
             ]
