@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,9 +18,9 @@ from testflows._core.cli.arg.handlers.handler import Handler as HandlerBase
 from testflows._core.cli.arg.handlers.transform.nice import Handler as nice_handler
 from testflows._core.cli.arg.handlers.transform.short import Handler as short_handler
 from testflows._core.cli.arg.handlers.transform.dots import Handler as dots_handler
-from testflows._core.cli.arg.handlers.transform.index import Handler as index_handler
 from testflows._core.cli.arg.handlers.transform.compact import Handler as compact_handler
 from testflows._core.cli.arg.handlers.transform.slick import Handler as slick_handler
+from testflows._core.cli.arg.handlers.transform.raw import Handler as raw_handler
 
 class Handler(HandlerBase):
     @classmethod
@@ -31,9 +32,9 @@ class Handler(HandlerBase):
         transform_commands = parser.add_subparsers(title="commands", metavar="command",
             description=None, help=None)
         transform_commands.required = True
+        raw_handler.add_command(transform_commands)
         nice_handler.add_command(transform_commands)
         short_handler.add_command(transform_commands)
         slick_handler.add_command(transform_commands)
         dots_handler.add_command(transform_commands)
-        index_handler.add_command(transform_commands)
         compact_handler.add_command(transform_commands)
