@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +21,7 @@ import threading
 
 import testflows.settings as settings
 
+from .compress import CompressedFile
 from .transform.log.pipeline import RawLogPipeline
 from .transform.log.pipeline import NiceLogPipeline
 from .transform.log.pipeline import DotsLogPipeline
@@ -58,6 +60,8 @@ def cleanup():
         if not pid_exists(pid):
             try:
                 os.remove(file)
+            except PermissionError:
+                pass
             except OSError:
                 raise
 
@@ -65,7 +69,7 @@ def stdout_raw_handler():
     """Handler to output messages to sys.stdout
     using "raw" format.
     """
-    with open(settings.read_logfile, "a+", buffering=1, encoding="utf-8") as log:
+    with CompressedFile(settings.read_logfile) as log:
         log.seek(0)
         RawLogPipeline(log, sys.stdout, tail=True).run()
 
@@ -73,7 +77,7 @@ def stdout_slick_handler():
     """Handler to output messages to sys.stdout
     using "slick" format.
     """
-    with open(settings.read_logfile, "a+", buffering=1, encoding="utf-8") as log:
+    with CompressedFile(settings.read_logfile) as log:
         log.seek(0)
         SlickLogPipeline(log, sys.stdout, tail=True).run()
 
@@ -81,7 +85,7 @@ def stdout_short_handler():
     """Handler to output messages to sys.stdout
     using "short" format.
     """
-    with open(settings.read_logfile, "a+", buffering=1, encoding="utf-8") as log:
+    with CompressedFile(settings.read_logfile) as log:
         log.seek(0)
         ShortLogPipeline(log, sys.stdout, tail=True).run()
 
@@ -89,7 +93,7 @@ def stdout_nice_handler():
     """Handler to output messages to sys.stdout
     using "nice" format.
     """
-    with open(settings.read_logfile, "a+", buffering=1, encoding="utf-8") as log:
+    with CompressedFile(settings.read_logfile) as log:
         log.seek(0)
         NiceLogPipeline(log, sys.stdout, tail=True).run()
 
@@ -97,7 +101,7 @@ def stdout_dots_handler():
     """Handler to output messages to sys.stdout
     using "dots" format.
     """
-    with open(settings.read_logfile, "a+", buffering=1, encoding="utf-8") as log:
+    with CompressedFile(settings.read_logfile) as log:
         log.seek(0)
         DotsLogPipeline(log, sys.stdout, tail=True).run()
 
@@ -106,22 +110,34 @@ def stdout_silent_handler():
     """
     pass
 
-def init():
-    """Initialization before we run the first test.
-    """
-    cleanup()
-
+def start_output_handler():
     output_handler_map = {
         "raw": stdout_raw_handler,
         "slick": stdout_slick_handler,
         "nice": stdout_nice_handler,
-        "silent": stdout_silent_handler,
         "quiet": stdout_silent_handler,
         "short": stdout_short_handler,
         "dots": stdout_dots_handler,
     }
-    # start stdout output handler
+
     handler = threading.Thread(target=output_handler_map[settings.output_format])
     handler.name = "tfs-output"
     handler.start()
+
+def start_database_handler():
+    if not settings.database:
+        return
+
+    from testflows.database import database_handler
+
+    handler = threading.Thread(target=database_handler)
+    handler.name = 'tfs-database'
+    handler.start()
+
+def init():
+    """Initialization before we run the first test.
+    """
+    cleanup()
+    start_output_handler()
+    start_database_handler()
     return True
