@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +14,7 @@
 # limitations under the License.
 import threading
 
-from testflows._core.message import Message, ResultMessages
+from testflows._core.message import Message
 from testflows._core.testtype import TestType
 from .read import transform as read_transform
 from .parse import transform as parse_transform
@@ -24,14 +25,13 @@ from .stop import transform as stop_transform
 from .raw import transform as raw_transform
 from .short import transform as short_transform
 from .slick import transform as slick_transform
-from .index import transform as index_transform
 from .read_and_filter import transform as read_and_filter_transform
 from .report.passing import transform as passing_report_transform
 from .report.fails import transform as fails_report_transform
 from .report.totals import transform as totals_report_transform
 from .report.version import transform as version_report_transform
 from .report.results import transform as results_transform
-from .report.map import transform as map_transform
+#from .report.map import transform as map_transform
 
 class Pipeline(object):
     """Combines multiple steps into a pipeline
@@ -89,8 +89,8 @@ class RawLogPipeline(Pipeline):
         stop_event = threading.Event()
 
         steps = [
-            read_transform(input, tail=tail),
-            raw_transform(stop_event),
+            read_transform(input, tail=tail, stop=stop_event),
+            raw_transform(),
             write_transform(output),
             stop_transform(stop_event)
         ]
@@ -101,7 +101,7 @@ class ShortLogPipeline(Pipeline):
         stop_event = threading.Event()
 
         steps = [
-            read_transform(input, tail=tail),
+            read_transform(input, tail=tail, stop=stop_event),
             parse_transform(stop_event),
             fanout(
                 short_transform(),
@@ -123,10 +123,10 @@ class NiceLogPipeline(Pipeline):
         stop_event = threading.Event()
 
         steps = [
-            read_transform(input, tail=tail),
+            read_transform(input, tail=tail, stop=stop_event),
             parse_transform(stop_event),
             fanout(
-                nice_transform(stop_event),
+                nice_transform(),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
                 totals_report_transform(stop_event),
@@ -145,7 +145,7 @@ class SlickLogPipeline(Pipeline):
         stop_event = threading.Event()
 
         steps = [
-            read_transform(input, tail=tail),
+            read_transform(input, tail=tail, stop=stop_event),
             parse_transform(stop_event),
             fanout(
                 slick_transform(),
@@ -167,7 +167,7 @@ class DotsLogPipeline(Pipeline):
         stop_event = threading.Event()
 
         steps = [
-            read_transform(input, tail=tail),
+            read_transform(input, tail=tail, stop=stop_event),
             parse_transform(stop_event),
             fanout(
                 dots_transform(stop_event),
@@ -188,14 +188,15 @@ class TotalsReportLogPipeline(Pipeline):
     def __init__(self, input, output):
         stop_event = threading.Event()
 
-        message_types = [Message.TEST] + ResultMessages
-        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+        message_types = [Message.TEST.name, Message.RESULT.name, Message.STOP.name]
+        grep = "grep -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
 
         steps = [
-            read_and_filter_transform(input, command=command),
-            parse_transform(stop_event),
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            parse_transform(),
             fanout(
-                totals_report_transform(stop_event),
+                totals_report_transform(stop_event, divider=""),
             ),
             fanin(
                 "".join
@@ -209,14 +210,15 @@ class FailsReportLogPipeline(Pipeline):
     def __init__(self, input, output):
         stop_event = threading.Event()
 
-        message_types = [Message.TEST] + ResultMessages
-        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+        message_types = [Message.RESULT.name, Message.STOP.name]
+        grep = "grep -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
 
         steps = [
-            read_and_filter_transform(input, command=command),
-            parse_transform(stop_event),
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            parse_transform(),
             fanout(
-                fails_report_transform(stop_event),
+                fails_report_transform(stop_event, divider=""),
             ),
             fanin(
                 "".join
@@ -230,14 +232,14 @@ class PassingReportLogPipeline(Pipeline):
     def __init__(self, input, output):
         stop_event = threading.Event()
 
-        message_types = [Message.TEST] + ResultMessages
-        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
-
+        message_types = [Message.RESULT.name, Message.STOP.name]
+        grep = "grep -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
         steps = [
-            read_and_filter_transform(input, command=command),
-            parse_transform(stop_event),
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            parse_transform(),
             fanout(
-                passing_report_transform(stop_event),
+                passing_report_transform(stop_event, divider=""),
             ),
             fanin(
                 "".join
@@ -251,14 +253,14 @@ class VersionReportLogPipeline(Pipeline):
     def __init__(self, input, output):
         stop_event = threading.Event()
 
-        message_types = [Message.VERSION] + ResultMessages
-        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
-
+        message_types = [Message.VERSION.name, Message.STOP.name]
+        grep = "grep -m2 -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
         steps = [
-            read_and_filter_transform(input, command=command),
-            parse_transform(stop_event),
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            parse_transform(),
             fanout(
-                version_report_transform(stop_event),
+                version_report_transform(stop_event, divider=""),
             ),
             fanin(
                 "".join
@@ -273,11 +275,10 @@ class MapLogPipeline(Pipeline):
         stop_event = threading.Event()
         message_types = [Message.TEST]
         command = f"grep -m1 -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
-
         steps = [
             read_and_filter_transform(input, command=command),
             parse_transform(stop_event),
-            map_transform(maps, stop_event),
+            #map_transform(maps, stop_event),
             stop_transform(stop_event)
         ]
         super(MapLogPipeline, self).__init__(steps)
@@ -285,13 +286,29 @@ class MapLogPipeline(Pipeline):
 class ResultsLogPipeline(Pipeline):
     def __init__(self, input, results):
         stop_event = threading.Event()
-        message_types = [Message.VERSION, Message.TEST] + ResultMessages
-        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
-
+        message_types = [
+            Message.PROTOCOL.name,
+            Message.VERSION.name,
+            Message.TEST.name,
+            Message.RESULT.name,
+            Message.MAP.name,
+            Message.NODE.name,
+            Message.ATTRIBUTE.name,
+            Message.TAG.name,
+            Message.ARGUMENT.name,
+            Message.REQUIREMENT.name,
+            Message.EXAMPLE.name,
+            Message.TICKET.name,
+            Message.VALUE.name,
+            Message.METRIC.name,
+            Message.STOP.name
+        ]
+        grep = "grep -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
         steps = [
-            read_and_filter_transform(input, command=command),
+            read_and_filter_transform(input, command=command, stop=stop_event),
             parse_transform(stop_event),
-            results_transform(results, stop_event),
+            results_transform(results),
             stop_transform(stop_event)
         ]
         super(ResultsLogPipeline, self).__init__(steps)
@@ -299,28 +316,32 @@ class ResultsLogPipeline(Pipeline):
 class CompactRawLogPipeline(Pipeline):
     def __init__(self, input, output, steps=True):
         stop_event = threading.Event()
-        message_types = [Message.VERSION, Message.TEST] + ResultMessages
-        test_types = [TestType.Module, TestType.Suite, TestType.Test]
-        command = (f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),"
-            + (f"\"[^\"]+\",[0-9]+,({'|'.join([str(t) for t in test_types])})," if not steps else "")
+        message_types = [
+            Message.PROTOCOL.name,
+            Message.VERSION.name,
+            Message.TEST.name,
+            Message.RESULT.name,
+            Message.MAP.name,
+            Message.NODE.name,
+            Message.ATTRIBUTE.name,
+            Message.TAG.name,
+            Message.ARGUMENT.name,
+            Message.REQUIREMENT.name,
+            Message.EXAMPLE.name,
+            Message.TICKET.name,
+            Message.VALUE.name,
+            Message.METRIC.name,
+            Message.STOP.name
+        ]
+        test_types = [TestType.Module.name, TestType.Suite.name, TestType.Test.name]
+        command = "grep -E '^{\"message_keyword\":\""
+        command = (f"{command}({'|'.join(message_types)})\""
+            + ((".+\"test_type\":\"" + f"({'|'.join(test_types)})\"") if not steps else "")
             + "'")
-
         steps = [
-            read_and_filter_transform(input, command=command),
-            raw_transform(stop_event),
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            raw_transform(),
             write_transform(output),
             stop_transform(stop_event)
         ]
         super(CompactRawLogPipeline, self).__init__(steps)
-
-class IndexLogPipeline(Pipeline):
-    def __init__(self, input, output):
-        stop_event = threading.Event()
-
-        steps = [
-            read_and_filter_transform(input, command=f"grep -E '^{Message.TEST},'"),
-            index_transform(stop_event),
-            write_transform(output),
-            stop_transform(stop_event)
-        ]
-        super(IndexLogPipeline, self).__init__(steps)
