@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,17 +15,23 @@
 import sys
 import subprocess
 
-def transform(file, command, tail=False):
+from testflows._core.message import Message
+
+def transform(file, command, tail=False, stop=None):
     """Read lines from a file-like object and filter them using
     Unix tail and grep utilities.
 
     :param file: open file handle
-    :pram
+    :param command: filter command (like grep)
     :param tail: tail mode, default: False
+    :param stop: stop event
     """
     yield None
 
-    process = subprocess.Popen(command, stdin=file, stdout=subprocess.PIPE, shell=True)
+    stop_keyword = ('{"message_keyword":"%s"' % str(Message.STOP)).encode("utf-8")
+    stop_keyword_len = len(stop_keyword)
+
+    process = subprocess.Popen(f"tfs transform raw | {command}", stdin=file, stdout=subprocess.PIPE, shell=True)
     while True:
         line = process.stdout.readline()
         if line == b"":
@@ -32,5 +39,7 @@ def transform(file, command, tail=False):
                 break
             else:
                 continue
+        if stop and line[:stop_keyword_len] == stop_keyword:
+            stop.set()
         yield line.decode("utf-8")
 
