@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,9 +15,9 @@
 from testflows._core.test import TestBase
 from testflows._core.test import Module, Suite, Test, Step, NullStep, run
 from testflows._core.test import TestStep, TestCase, TestSuite, TestModule
-from testflows._core.test import Attributes, Requirements, Users, Tickets, Examples
+from testflows._core.test import Attributes, Requirements, Examples
 from testflows._core.test import Name, Description, Uid, Tags, TestClass, Context
-from testflows._core.test import Feature, Background, Scenario
+from testflows._core.test import Feature, Cleanup, Background, Scenario
 from testflows._core.test import Given, When, Then, And, But, By, Finally
 from testflows._core.test import Steps
 from testflows._core.test import TestFeature, TestScenario
@@ -26,5 +27,6 @@ from testflows._core.objects import *
 from testflows._core.name import *
 from testflows._core.flags import *
 from testflows._core import __author__, __version__, __license__
+from testflows._core import threading
 
 import testflows._core.utils as utils
